@@ -34,10 +34,10 @@ G_BEGIN_DECLS
 void rsvg_start_text (RsvgHandle *ctx, RsvgPropertyBag *atts);
 char * rsvg_make_valid_utf8 (const char *str);
 
-typedef struct _RsvgDefsDrawableText RsvgDefsDrawableText;
+typedef struct _RsvgNodeText RsvgNodeText;
 
-struct _RsvgDefsDrawableText {
-	RsvgDefsDrawable super;
+struct _RsvgNodeText {
+	RsvgNode super;
 	void * chunk;
 };
 
